#[derive(AutoFrom)]Expand description
Derive macro generating an impl of the trait From for all types
inside tuple variants with one type
#[derive(AutoFrom)]Derive macro generating an impl of the trait From for all types
inside tuple variants with one type